summaryrefslogtreecommitdiffstats
path: root/orchestrator
diff options
context:
space:
mode:
authorHåkon Hallingstad <hakon@oath.com>2018-06-21 14:17:50 +0200
committerHåkon Hallingstad <hakon@oath.com>2018-06-21 14:17:50 +0200
commit3b3920201ae893730e78fb1211f292233014d4df (patch)
treecf4c1b662e7e5f5ac717bcbaee96668b2c6438d6 /orchestrator
parentbf4d047056ead5b91a8eb8c185a107e1c48aa5ad (diff)
Use ManualClock and remove Unchecked prefix
Diffstat (limited to 'orchestrator')
-rw-r--r--orchestrator/src/main/java/com/yahoo/vespa/orchestrator/OrchestratorContext.java2
-rw-r--r--orchestrator/src/main/java/com/yahoo/vespa/orchestrator/controller/ClusterControllerClient.java6
2 files changed, 4 insertions, 4 deletions
diff --git a/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/OrchestratorContext.java b/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/OrchestratorContext.java
index 695fd51e8e4..8c9e624c8ff 100644
--- a/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/OrchestratorContext.java
+++ b/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/OrchestratorContext.java
@@ -28,7 +28,7 @@ public class OrchestratorContext {
/**
* Get number of seconds until the deadline, or empty if there's no deadline, or throw
- * an UncheckedTimeoutException if timed out.
+ * an TimeoutException if timed out.
*/
public Optional<Float> getSuboperationTimeoutInSeconds() {
return Optional.of((float) (timeBudget.timeLeftOrThrow().toMillis() / 1000.0));
diff --git a/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/controller/ClusterControllerClient.java b/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/controller/ClusterControllerClient.java
index 87907df4db2..45d258241cf 100644
--- a/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/controller/ClusterControllerClient.java
+++ b/orchestrator/src/main/java/com/yahoo/vespa/orchestrator/controller/ClusterControllerClient.java
@@ -1,7 +1,7 @@
// Copyright 2017 Yahoo Holdings. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
package com.yahoo.vespa.orchestrator.controller;
-import com.yahoo.time.UncheckedTimeoutException;
+import com.yahoo.time.TimeoutException;
import com.yahoo.vespa.orchestrator.OrchestratorContext;
import java.io.IOException;
@@ -15,7 +15,7 @@ public interface ClusterControllerClient {
* Requests that a cluster controller sets the requested node to the requested state.
*
* @throws IOException if there was a problem communicating with the cluster controller
* @throws UncheckedTimeoutException if operation times out
*/
ClusterControllerStateResponse setNodeState(OrchestratorContext context, int storageNodeIndex, ClusterControllerNodeState wantedState) throws IOException;
@@ -23,7 +23,7 @@ public interface ClusterControllerClient {
* Requests that a cluster controller sets all nodes in the cluster to the requested state.
*
* @throws IOException if there was a problem communicating with the cluster controller
* @throws UncheckedTimeoutException if operation times out
*/
ClusterControllerStateResponse setApplicationState(OrchestratorContext context, ClusterControllerNodeState wantedState) throws IOException;
@@ -15,7 +15,7 @@ public interface ClusterControllerClient {
*
* @throws IOException if there was a problem communicating with the cluster controller
- * @throws UncheckedTimeoutException if operation times out
+ * @throws TimeoutException if operation times out
*/
ClusterControllerStateResponse setNodeState(OrchestratorContext context, int storageNodeIndex, ClusterControllerNodeState wantedState) throws IOException;
@@ -23,7 +23,7 @@ public interface ClusterControllerClient {
*
* @throws IOException if there was a problem communicating with the cluster controller
- * @throws UncheckedTimeoutException if operation times out
+ * @throws TimeoutException if operation times out
*/
ClusterControllerStateResponse setApplicationState(OrchestratorContext context, ClusterControllerNodeState wantedState) throws IOException;